pub fn compile_sva_compiler() -> SvaCompilerExpand description
P2: Specialize the specializer for SVA synthesis → SVA compiler.
Returns a compiler that, for any spec, produces a compiled generator.
pub fn compile_sva_compiler() -> SvaCompilerP2: Specialize the specializer for SVA synthesis → SVA compiler.
Returns a compiler that, for any spec, produces a compiled generator.